<?php
/**
 * @copyright Copyright (c) 2021 Aurora Creation Sp. z o.o. (http://auroracreation.com)
 */

namespace Aurora\Santander\Helper;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Filesystem\DirectoryList;

class Config
{
    const API_LOGIN = 'santander_configuration/auto_update/api_login';
    const API_PASSWD = 'santander_configuration/auto_update/api_password';
    const API_SHOP_NUMBER = 'santander_configuration/auto_update/shop_id';
    const API_CERT = 'santander_configuration/auto_update/cert';
    const API_CERT_PASSWD = 'santander_configuration/auto_update/cert_password';
    const MODULE_PREFIX = 'santander_configuration/logger/module_prefix';

    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;

    /**
     * @var DirectoryList
     */
    private $directoryList;

    /**
     * @param ScopeConfigInterface $scopeConfig
     * @param DirectoryList $directoryList
     */
    public function __construct(
        ScopeConfigInterface $scopeConfig,
        DirectoryList        $directoryList
    )
    {
        $this->scopeConfig = $scopeConfig;
        $this->directoryList = $directoryList;
    }

    /**
     * @return string
     */
    public function getLogin()
    {
        return $this->scopeConfig->getValue(self::API_LOGIN);
    }

    /**
     * @return string
     */
    public function getPassword()
    {
        return $this->scopeConfig->getValue(self::API_PASSWD);
    }

    /**
     * @return string
     */
    public function getShopNumber()
    {
        return $this->scopeConfig->getValue(self::API_SHOP_NUMBER);
    }

    /**
     * @return string
     */
    public function getCertPath()
    {
        $cert = $this->scopeConfig->getValue(self::API_CERT);

        return sprintf('%s/%s/%s', $this->directoryList->getPath('pub'), 'cert', $cert);
    }

    /**
     * @return string
     */
    public function getCertPasswd()
    {
        return $this->scopeConfig->getValue(self::API_CERT_PASSWD);
    }

    /**
     * @return string
     */
    public function getPrefix()
    {
        return $this->scopeConfig->getValue(self::MODULE_PREFIX);
    }
}